sqlobject.tests.test_slice module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_slice module

class `sqlobject.tests.test_slice.` `Counter`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = counter
  property `number`
  `q` = counter
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_slice.Counter`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'counter'

class `sqlobject.tests.test_slice.` `TestSlice`

  Bases: `object`

  `counterEqual`(counters, value)
  `setup_method`(meth)
  `test_slice`()

`sqlobject.tests.test_slice.` `listrange`(*args)

  Always return a list, for py3k compatibility